@@ -3,7 +3,7 @@
 from .cuda_collect_env import main as cuda_collect_env
 from .debug import paste, reload
 from .latex import add_hat_in_the_latex_style, to_the_latex_style
-from .load import load
+from .load import load, load_from_a_package
 from .mat2py import *
 from .misc import (
     connect_nums,
