@@ -57,6 +57,11 @@ def load(lpath, show=False):
         import pymatreader
 
         obj = pymatreader.read_mat(lpath)
+    # xml
+    if lpath.endswith("xml"):
+        from ._xml2dict import xml2dict
+
+        obj = xml2dict(lpath)
 
     if show:
         print("\nLoaded: {}\n".format(lpath))
